@@ -219,6 +219,8 @@ def generate_backtest_result(all_para_combination, number_of_core=8, risk_free_r
     pool = mp.Pool(processes=number_of_core)
     pool.map(mp_cal_performance, cal_performance_list)
     pool.close()
+    # for c in cal_performance_list:
+    #     mp_cal_performance(c)
 
     df_backtest_result = pd.DataFrame(list(manager_list))
     df_backtest_result = df_backtest_result.sort_values(by='reference_index')
@@ -508,7 +510,15 @@ def cal_performance(para_combination):
         else:
             df_backtest = pd.read_csv(save_path, index_col=0)  # Daraframe that may not be daily
 
-        df_backtest['date'] = pd.to_datetime(df_backtest['date'], format='%Y-%m-%d')
+        first_date_str = df_backtest.at[df_backtest.index[0],  'date']
+        if '-' in first_date_str:
+            df_backtest['date'] = pd.to_datetime(df_backtest['date'], format='%Y-%m-%d')
+        else:
+            try:
+                df_backtest['date'] = pd.to_datetime(df_backtest['date'], format='%Y%m%d')
+            except:
+                df_backtest['date'] = pd.to_datetime(df_backtest['date'])
+
         df_backtest = df_backtest.loc[(df_backtest['date'] >= start_date) & (df_backtest['date'] <= end_date)]
         df_backtest = df_backtest.reset_index(drop=True)  # Reset Index
         df_daily = df_backtest
